from a10sdk.common.A10BaseClass import A10BaseClass


class RouteMap(A10BaseClass):
    
    """Class Description::
    Configure route-map.

    Class route-map supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action: {"optional": false, "enum": ["permit", "deny"], "type": "string", "description": "'permit': Route map permits set operations; 'deny': Route map denies set operations; ", "format": "enum"}
    :param tag: {"description": "Route map tag", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}
    :param sequence: {"description": "Sequence to insert to/delete from existing route-map entry", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/route-map/{tag}+{action}+{sequence}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "tag","action","sequence"]

        self.b_key = "route-map"
        self.a10_url="/axapi/v3/route-map/{tag}+{action}+{sequence}"
        self.DeviceProxy = ""
        self.action = ""
        self.tag = ""
        self.A10WW_set = {}
        self.match = {}
        self.sequence = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RulesList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ext_list_value: {"type": "string", "description": "An ordered list as a regular-expression", "format": "string-rlx"}
    :param ext_list_action: {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify community to reject; 'permit': Specify community to accept; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rules-list"
        self.DeviceProxy = ""
        self.ext_list_value = ""
        self.ext_list_action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExpandedNum(A10BaseClass):
    
    """Class Description::
    Configure Expanded number Community-list.

    Class expanded-num supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ext_list_num: {"description": "Extended Community list number (expanded)", "format": "number", "type": "number", "maximum": 199, "minimum": 100, "optional": false}
    :param rules_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ext-list-value": {"type": "string", "description": "An ordered list as a regular-expression", "format": "string-rlx"}, "ext-list-action": {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify community to reject; 'permit': Specify community to accept; ", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/extcommunity-list/expanded-num/{ext_list_num}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ext_list_num"]

        self.b_key = "expanded-num"
        self.a10_url="/axapi/v3/ip/extcommunity-list/expanded-num/{ext_list_num}"
        self.DeviceProxy = ""
        self.ext_list_num = ""
        self.rules_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Method(A10BaseClass):
    
    """Class Description::
    Define the health method object, default is ICMP.

    Class method supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "method"
        self.a10_url="/axapi/v3/health/monitor/{name}/method"
        self.DeviceProxy = ""
        self.ftp = {}
        self.udp = {}
        self.sip = {}
        self.http = {}
        self.https = {}
        self.compound = {}
        self.database = {}
        self.smtp = {}
        self.ntp = {}
        self.rtsp = {}
        self.snmp = {}
        self.tcp = {}
        self.pop3 = {}
        self.radius = {}
        self.external = {}
        self.dns = {}
        self.ldap = {}
        self.icmp = {}
        self.kerberos_kdc = {}
        self.imap = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CacheList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cache_ttl: {"type": "number", "format": "number"}
    :param additional_records: {"type": "number", "format": "number"}
    :param question_records: {"type": "number", "format": "number"}
    :param cache_dns_flag: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param answer_records: {"type": "number", "format": "number"}
    :param alias: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param cache_length: {"type": "number", "format": "number"}
    :param authority_records: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cache-list"
        self.DeviceProxy = ""
        self.cache_ttl = ""
        self.additional_records = ""
        self.question_records = ""
        self.cache_dns_flag = ""
        self.answer_records = ""
        self.alias = ""
        self.cache_length = ""
        self.authority_records = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SessionList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param aging: {"type": "number", "format": "number"}
    :param hits: {"type": "number", "format": "number"}
    :param update: {"type": "number", "format": "number"}
    :param client: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param last_second_hits: {"type": "number", "format": "number"}
    :param mode: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param ttl: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param best: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "session-list"
        self.DeviceProxy = ""
        self.aging = ""
        self.hits = ""
        self.update = ""
        self.client = ""
        self.last_second_hits = ""
        self.mode = ""
        self.ttl = ""
        self.best = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param total_sessions: {"type": "number", "format": "number"}
    :param cache_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cache-ttl": {"type": "number", "format": "number"}, "additional-records": {"type": "number", "format": "number"}, "question-records": {"type": "number", "format": "number"}, "cache-dns-flag": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "answer-records": {"type": "number", "format": "number"}, "alias": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "cache-length": {"type": "number", "format": "number"}, "optional": true, "authority-records": {"type": "number", "format": "number"}}}]}
    :param state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param session_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"aging": {"type": "number", "format": "number"}, "hits": {"type": "number", "format": "number"}, "update": {"type": "number", "format": "number"}, "client": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "last-second-hits": {"type": "number", "format": "number"}, "mode": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "ttl": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "best": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param matched: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.total_sessions = ""
        self.cache_list = []
        self.state = ""
        self.session_list = []
        self.matched = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnsARecord(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns-a-record"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Service(A10BaseClass):
    
    """Class Description::
    Operational Status for the object service.

    Class service supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dns_ns_record_list: {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"oper": {"type": "object", "properties": {"last-server": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}"}
    :param service_port: {"description": "Port number of the service", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}
    :param dns_mx_record_list: {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"oper": {"type": "object", "properties": {"last-server": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-mx-record/{mx-name}"}
    :param service_name: {"description": "Specify the service name for the zone, * for wildcard", "format": "string-rlx", "minLength": 1, "oid": "1002", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "service"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.dns_a_record = {}
        self.dns_ns_record_list = []
        self.service_port = ""
        self.dns_mx_record_list = []
        self.service_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class StunTimeout(A10BaseClass):
    
    """Class Description::
    Set STUN timeout.

    Class stun-timeout supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param udp_list: {"minItems": 1, "items": {"type": "udp"}, "uniqueItems": true, "array": [{"required": ["port-start", "port-end"], "properties": {"port-start": {"description": "Port Range (Port Range Start)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "port-end": {"description": "Port Range (Port Range End)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "timeout": {"description": "STUN timeout in minutes (default: 2 minutes)", "format": "number", "type": "number", "maximum": 60, "minimum": 0, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/lsn/stun-timeout/udp/{port-start}+{port-end}"}
    :param tcp_list: {"minItems": 1, "items": {"type": "tcp"}, "uniqueItems": true, "array": [{"required": ["port-start", "port-end"], "properties": {"port-start": {"description": "Port Range (Port Range Start)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "port-end": {"description": "Port Range (Port Range End)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "timeout": {"description": "STUN timeout in minutes (default: 2 minutes)", "format": "number", "type": "number", "maximum": 60, "minimum": 0, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/lsn/stun-timeout/tcp/{port-start}+{port-end}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/stun-timeout`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "stun-timeout"
        self.a10_url="/axapi/v3/cgnv6/lsn/stun-timeout"
        self.DeviceProxy = ""
        self.udp_list = []
        self.tcp_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TimeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param day_of_month: {"description": "Day of the Month", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}
    :param time: {"type": "string", "description": "Current Time", "format": "time"}
    :param month_2: {"enum": ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"], "type": "string", "description": "'January': Month of the year; 'February': Month of the year; 'March': Month of the year; 'April': Month of the year; 'May': Month of the year; 'June': Month of the year; 'July': Month of the year; 'August': Month of the year; 'September': Month of the year; 'October': Month of the year; 'November': Month of the year; 'December': Month of the year; ", "format": "enum"}
    :param month: {"enum": ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"], "type": "string", "description": "'January': Month of the year; 'February': Month of the year; 'March': Month of the year; 'April': Month of the year; 'May': Month of the year; 'June': Month of the year; 'July': Month of the year; 'August': Month of the year; 'September': Month of the year; 'October': Month of the year; 'November': Month of the year; 'December': Month of the year; ", "format": "enum"}
    :param year: {"description": "Year", "minimum": 2005, "type": "number", "maximum": 2035, "format": "number"}
    :param day_of_month_2: {"description": "Day of the Month", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "time-cfg"
        self.DeviceProxy = ""
        self.day_of_month = ""
        self.time = ""
        self.month_2 = ""
        self.month = ""
        self.year = ""
        self.day_of_month_2 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Set(A10BaseClass):
    
    """    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Set the Time and Date.

    Class set supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/clock/set`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "set"
        self.a10_url="/axapi/v3/clock/set"
        self.DeviceProxy = ""
        self.time_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Lsn(A10BaseClass):
    
    """Class Description::
    Enable LSN group traps.

    Class lsn supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param all: {"default": 0, "optional": true, "type": "number", "description": "Enable all system group traps", "format": "flag"}
    :param traffic_exceeded: {"default": 0, "optional": true, "type": "number", "description": "Enable LSN trap when NAT pool reaches the threshold", "format": "flag"}
    :param per_ip_port_usage_threshold: {"default": 0, "optional": true, "type": "number", "description": "Enable LSN trap when IP total port usage reaches the threshold (default 64512)", "format": "flag"}
    :param total_port_usage_threshold: {"default": 0, "optional": true, "type": "number", "description": "Enable LSN trap when NAT total port usage reaches the threshold (default 655350000)", "format": "flag"}
    :param max_port_threshold: {"description": "Maximum threshold", "format": "number", "default": 655350000, "optional": true, "maximum": 655355000, "minimum": 10000, "type": "number"}
    :param max_ipport_threshold: {"description": "Maximum threshold", "format": "number", "default": 64512, "optional": true, "maximum": 64512, "minimum": 10000, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/lsn`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "lsn"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/lsn"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.traffic_exceeded = ""
        self.per_ip_port_usage_threshold = ""
        self.total_port_usage_threshold = ""
        self.max_port_threshold = ""
        self.max_ipport_threshold = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ConnectionReuse(A10BaseClass):
    
    """Class Description::
    Connection Reuse.

    Class connection-reuse supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param preopen: {"default": 0, "optional": true, "type": "number", "description": "Preopen server connection", "format": "flag"}
    :param name: {"description": "Connection Reuse Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param keep_alive_conn: {"default": 0, "optional": true, "type": "number", "description": "Keep a number of server connections open", "format": "flag"}
    :param timeout: {"description": "Timeout in seconds. Multiple of 60 (def 2400)", "format": "number", "default": 2400, "optional": true, "maximum": 3600, "minimum": 60, "type": "number"}
    :param num_conn_per_port: {"description": "Connections per Server Port (default 100)", "format": "number", "default": 100, "optional": true, "maximum": 1024, "minimum": 1, "type": "number"}
    :param limit_per_server: {"description": "Max Server Connections allowed (Connections per Server Port (default 1000))", "format": "number", "default": 1000, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/connection-reuse/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "connection-reuse"
        self.a10_url="/axapi/v3/slb/template/connection-reuse/{name}"
        self.DeviceProxy = ""
        self.preopen = ""
        self.name = ""
        self.keep_alive_conn = ""
        self.timeout = ""
        self.num_conn_per_port = ""
        self.limit_per_server = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dns(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cache_action: {"default": "cache-disable", "enum": ["cache-disable", "cache-enable"], "type": "string", "description": "'cache-disable': Disable dns cache; 'cache-enable': Enable dns cache; ", "format": "enum"}
    :param weight: {"description": "Weight for cache entry", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param ttl: {"description": "TTL for cache entry (TTL in seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns"
        self.DeviceProxy = ""
        self.cache_action = ""
        self.weight = ""
        self.ttl = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Lid(A10BaseClass):
    
    """Class Description::
    Limit ID.

    Class lid supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param over_limit_action: {"default": 0, "optional": true, "type": "number", "description": "Action when exceeds limit", "format": "flag"}
    :param log: {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}
    :param lidnum: {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}
    :param action_value: {"optional": true, "enum": ["dns-cache-disable", "dns-cache-enable", "forward"], "type": "string", "description": "'dns-cache-disable': Disable DNS cache when it exceeds limit; 'dns-cache-enable': Enable DNS cache when it exceeds limit; 'forward': Forward the traffic even it exceeds limit; ", "format": "enum"}
    :param per: {"description": "Per (Number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param lockout: {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}
    :param conn_rate_limit: {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}
    :param log_interval: {"description": "Log interval (minute, by default system will log every over limit instance)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/template/dns/{name}/class-list/lid/{lidnum}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "lidnum"]

        self.b_key = "lid"
        self.a10_url="/axapi/v3/cgnv6/template/dns/{name}/class-list/lid/{lidnum}"
        self.DeviceProxy = ""
        self.over_limit_action = ""
        self.log = ""
        self.lidnum = ""
        self.action_value = ""
        self.per = ""
        self.lockout = ""
        self.dns = {}
        self.conn_rate_limit = ""
        self.log_interval = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Authentication(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param encrypted: {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param password: {"minLength": 1, "maxLength": 16, "type": "string", "description": "Key String", "format": "password"}
    :param method: {"enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': Keyed MD5; 'meticulous-md5': Meticulous Keyed MD5; 'meticulous-sha1': Meticulous Keyed SHA1; 'sha1': Keyed SHA1; 'simple': Simple Password; ", "format": "enum"}
    :param key_id: {"description": "Key ID", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "authentication"
        self.DeviceProxy = ""
        self.encrypted = ""
        self.password = ""
        self.method = ""
        self.key_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IntervalCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param interval: {"description": "Transmit interval between BFD packets (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}
    :param min_rx: {"description": "Minimum receive interval capability (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}
    :param multiplier: {"description": "Multiplier value used to compute holddown (value used to multiply the interval)", "minimum": 3, "type": "number", "maximum": 50, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "interval-cfg"
        self.DeviceProxy = ""
        self.interval = ""
        self.min_rx = ""
        self.multiplier = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bfd(A10BaseClass):
    
    """Class Description::
    Configure BFD (Bidirectional Forwarding Detection).

    Class bfd supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param demand: {"default": 0, "optional": true, "type": "number", "description": "Demand mode", "format": "flag"}
    :param echo: {"default": 0, "optional": true, "type": "number", "description": "Enable BFD Echo", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/lif/{ifnum}/bfd`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "bfd"
        self.a10_url="/axapi/v3/interface/lif/{ifnum}/bfd"
        self.DeviceProxy = ""
        self.authentication = {}
        self.demand = ""
        self.interval_cfg = {}
        self.echo = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IfStatsList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param counter_sample_records: {"type": "number", "format": "number"}
    :param packet_sample_records: {"type": "number", "format": "number"}
    :param if_num: {"type": "number", "format": "number"}
    :param if_type: {"enum": ["Ethernet", "VE"], "type": "string", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "if-stats-list"
        self.DeviceProxy = ""
        self.counter_sample_records = ""
        self.packet_sample_records = ""
        self.if_num = ""
        self.if_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param if_stats_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"counter-sample-records": {"type": "number", "format": "number"}, "packet-sample-records": {"type": "number", "format": "number"}, "if-num": {"type": "number", "format": "number"}, "if-type": {"enum": ["Ethernet", "VE"], "type": "string", "format": "enum"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.if_stats_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Operational Status for the object global.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/sflow/global/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/sflow/global/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DnsARecordIpv4(A10BaseClass):
    
    """Class Description::
    Specify DNS Address Record.

    Class dns-a-record-ipv4 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param as_replace: {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}
    :param dns_a_record_ip: {"optional": false, "type": "string", "description": "Specify IP address", "format": "ipv4-address"}
    :param as_backup: {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}
    :param weight: {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}
    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}
    :param static: {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}
    :param ttl: {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}
    :param admin_ip: {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param no_resp: {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-a-record/dns-a-record-ipv4/{dns_a_record_ip}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "dns_a_record_ip"]

        self.b_key = "dns-a-record-ipv4"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-a-record/dns-a-record-ipv4/{dns_a_record_ip}"
        self.DeviceProxy = ""
        self.as_replace = ""
        self.dns_a_record_ip = ""
        self.as_backup = ""
        self.weight = ""
        self.disable = ""
        self.static = ""
        self.ttl = ""
        self.admin_ip = ""
        self.no_resp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AutoMap(A10BaseClass):
    
    """Class Description::
    Auto Mapping Options.

    Class auto-map supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param all: {"description": "All modules", "format": "flag", "default": 0, "optional": true, "not": "module-type", "type": "number"}
    :param module_disable: {"default": 0, "optional": true, "type": "number", "description": "Specify Disable Auto Map Module", "format": "flag"}
    :param module_type: {"not": "all", "optional": true, "enum": ["slb-virtual-server", "slb-device", "slb-server", "gslb-service-ip", "gslb-site", "gslb-group", "hostname"], "type": "string", "format": "enum-list"}
    :param ttl: {"description": "Specify Auto Map TTL (TTL, default is 300)", "format": "number", "default": 300, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/policy/{name}/auto-map`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "auto-map"
        self.a10_url="/axapi/v3/gslb/policy/{name}/auto-map"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.module_disable = ""
        self.module_type = ""
        self.ttl = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RangeList(A10BaseClass):
    
    """Class Description::
    IP Source NAT Static range list.

    Class range-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param global_start_ipv6_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Global Start IPv6 Address of this list", "format": "ipv6-address-plen"}
    :param v4_vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param global_netmaskv4: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Mask for this Address range", "format": "ipv4-netmask"}
    :param local_start_ipv6_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Local Start IPv6 Address of this list", "format": "ipv6-address-plen"}
    :param local_netmaskv4: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Mask for this Address range", "format": "ipv4-netmask"}
    :param local_start_ipv4_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Local Start IPv4 Address of this list", "format": "ipv4-address"}
    :param global_start_ipv4_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Global Start IPv4 Address of this list", "format": "ipv4-address"}
    :param v6_vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param v4_count: {"description": "Number of addresses to be translated in this range", "format": "number", "optional": true, "maximum": 200000, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param v6_count: {"description": "Number of addresses to be translated in this range", "format": "number", "optional": true, "maximum": 200000, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param name: {"description": "Name for this Static List", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/range-list/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "range-list"
        self.a10_url="/axapi/v3/ip/nat/range-list/{name}"
        self.DeviceProxy = ""
        self.global_start_ipv6_addr = ""
        self.v4_vrid = ""
        self.global_netmaskv4 = ""
        self.local_start_ipv6_addr = ""
        self.local_netmaskv4 = ""
        self.local_start_ipv4_addr = ""
        self.global_start_ipv4_addr = ""
        self.v6_vrid = ""
        self.v4_count = ""
        self.v6_count = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Isis(A10BaseClass):
    
    """Class Description::
    Enable isis traps.

    Class isis supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param isisOwnLSPPurge: {"default": 0, "optional": true, "type": "number", "description": "Enable isisOwnLSPPurge traps", "format": "flag"}
    :param isisOriginatingLSPBufferSizeMis: {"default": 0, "optional": true, "type": "number", "description": "Enable isisOriginatingLSPBufferSizeMismatch traps", "format": "flag"}
    :param isisAuthenticationFailure: {"default": 0, "optional": true, "type": "number", "description": "Enable isisAuthenticationFailure traps", "format": "flag"}
    :param isisAdjacencyChange: {"default": 0, "optional": true, "type": "number", "description": "Enable isisAdjacencyChange traps", "format": "flag"}
    :param isisMaxAreaAddressesMismatch: {"default": 0, "optional": true, "type": "number", "description": "Enable isisMaxAreaAddressesMismatch traps", "format": "flag"}
    :param isisProtocolsSupportedMismatch: {"default": 0, "optional": true, "type": "number", "description": "Enable isisProtocolsSupportedMismatch traps", "format": "flag"}
    :param isisSequenceNumberSkip: {"default": 0, "optional": true, "type": "number", "description": "Enable isisSequenceNumberSkip traps", "format": "flag"}
    :param isisAreaMismatch: {"default": 0, "optional": true, "type": "number", "description": "Enable isisAreaMismatch traps", "format": "flag"}
    :param isisLSPTooLargeToPropagate: {"default": 0, "optional": true, "type": "number", "description": "Enable isisLSPTooLargeToPropagate traps", "format": "flag"}
    :param isisDatabaseOverload: {"default": 0, "optional": true, "type": "number", "description": "Enable isisDatabaseOverload traps", "format": "flag"}
    :param isisRejectedAdjacency: {"default": 0, "optional": true, "type": "number", "description": "Enable isisRejectedAdjacency traps", "format": "flag"}
    :param isisAttemptToExceedMaxSequence: {"default": 0, "optional": true, "type": "number", "description": "Enable isisAttemptToExceedMaxSequence traps", "format": "flag"}
    :param isisIDLenMismatch: {"default": 0, "optional": true, "type": "number", "description": "Enable isisIDLenMismatch traps", "format": "flag"}
    :param isisAuthenticationTypeFailure: {"default": 0, "optional": true, "type": "number", "description": "Enable isisAuthenticationTypeFailure traps", "format": "flag"}
    :param isisVersionSkew: {"default": 0, "optional": true, "type": "number", "description": "Enable isisVersionSkew traps", "format": "flag"}
    :param isisManualAddressDrops: {"default": 0, "optional": true, "type": "number", "description": "Enable isisManualAddressDrops traps", "format": "flag"}
    :param isisCorruptedLSPDetected: {"default": 0, "optional": true, "type": "number", "description": "Enable isisCorruptedLSPDetected traps", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/routing/isis`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "isis"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/routing/isis"
        self.DeviceProxy = ""
        self.isisOwnLSPPurge = ""
        self.isisOriginatingLSPBufferSizeMis = ""
        self.isisAuthenticationFailure = ""
        self.isisAdjacencyChange = ""
        self.isisMaxAreaAddressesMismatch = ""
        self.isisProtocolsSupportedMismatch = ""
        self.isisSequenceNumberSkip = ""
        self.isisAreaMismatch = ""
        self.isisLSPTooLargeToPropagate = ""
        self.isisDatabaseOverload = ""
        self.isisRejectedAdjacency = ""
        self.isisAttemptToExceedMaxSequence = ""
        self.isisIDLenMismatch = ""
        self.isisAuthenticationTypeFailure = ""
        self.isisVersionSkew = ""
        self.isisManualAddressDrops = ""
        self.isisCorruptedLSPDetected = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """Class Description::
    Specify the LDAP server's hostname or IP address.

    Class host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ldap_hostname_list: {"minItems": 1, "items": {"type": "ldap-hostname"}, "uniqueItems": true, "array": [{"required": ["hostname"], "properties": {"port-cfg": {"type": "object", "properties": {"ssl": {"default": 0, "type": "number", "description": "Use SSL", "format": "flag"}, "port": {"description": "Specify the LDAP server's port (default 389 without ssl or 636 with ssl)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "timeout": {"description": "Specify the LDAP server's timeout (default 3)", "minimum": 1, "type": "number", "maximum": 60, "format": "number"}}}, "cn-value": {"description": "LDAP common name identifier (i.e.: cn, uid)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "hostname": {"description": "Hostname of LDAP server", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "dn-value": {"description": "LDAP distinguished name (dn)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/ldap-server/host/ldap-hostname/{hostname}"}
    :param ipv4_list: {"minItems": 1, "items": {"type": "ipv4"}, "uniqueItems": true, "array": [{"required": ["ipv4-addr"], "properties": {"port-cfg": {"type": "object", "properties": {"ssl": {"default": 0, "type": "number", "description": "Use SSL", "format": "flag"}, "port": {"description": "Specify the LDAP server's port (default 389 without ssl or 636 with ssl)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "timeout": {"description": "Specify the LDAP server's timeout (default 3)", "minimum": 1, "type": "number", "maximum": 60, "format": "number"}}}, "ipv4-addr": {"optional": false, "type": "string", "description": "IPV4 address of ldap server", "format": "ipv4-address"}, "cn-value": {"description": "LDAP common name identifier (i.e.: cn, uid)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "dn-value": {"description": "LDAP distinguished name (dn)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/ldap-server/host/ipv4/{ipv4-addr}"}
    :param ipv6_list: {"minItems": 1, "items": {"type": "ipv6"}, "uniqueItems": true, "array": [{"required": ["ipv6-addr"], "properties": {"port-cfg": {"type": "object", "properties": {"ssl": {"default": 0, "type": "number", "description": "Use SSL", "format": "flag"}, "port": {"description": "Specify the LDAP server's port (default 389 without ssl or 636 with ssl)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "timeout": {"description": "Specify the LDAP server's timeout (default 3)", "minimum": 1, "type": "number", "maximum": 60, "format": "number"}}}, "dn-value": {"description": "LDAP distinguished name (dn)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "cn-value": {"description": "LDAP common name identifier (i.e.: cn, uid)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "ipv6-addr": {"optional": false, "type": "string", "description": "IPV6 address of ldap server", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/ldap-server/host/ipv6/{ipv6-addr}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ldap-server/host`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "host"
        self.a10_url="/axapi/v3/ldap-server/host"
        self.DeviceProxy = ""
        self.ldap_hostname_list = []
        self.ipv4_list = []
        self.ipv6_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv6(A10BaseClass):
    
    """Class Description::
    IPv6 information.

    Class ipv6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ospf_list: {"minItems": 1, "items": {"type": "ospf"}, "uniqueItems": true, "array": [{"required": ["process-id"], "properties": {"default-metric": {"description": "Set metric of redistributed routes (Default metric)", "format": "number", "default": 20, "optional": true, "maximum": 16777214, "minimum": 1, "type": "number"}, "abr-type-option": {"description": "'cisco': Alternative ABR, Cisco implementation (RFC3509); 'ibm': Alternative ABR, IBM implementation (RFC3509); 'standard': Standard behavior (RFC2328); ", "format": "enum", "default": "cisco", "type": "string", "enum": ["cisco", "ibm", "standard"], "optional": true}, "auto-cost-reference-bandwidth": {"description": "Use reference bandwidth method to assign OSPF cost (The reference bandwidth in terms of Mbits per second)", "format": "number", "default": 10000, "optional": true, "maximum": 4294967, "minimum": 1, "type": "number"}, "router-id": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "router-id for the OSPF process (OSPFv3 router-id in IPv4 address format)", "format": "ipv4-address"}, "distribute-internal-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "area-ipv4": {"default": "255.255.255.255", "type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "cost": {"description": "Cost", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "type": {"enum": ["lw4o6", "nat64", "floating-ip", "ip-nat", "ip-nat-list", "vip", "vip-only-flagged"], "type": "string", "description": "'lw4o6': LW4O6 Prefix; 'nat64': NAT64 Prefix; 'floating-ip': Floating IP; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'vip': Virtual IP (VIP); 'vip-only-flagged': Selected Virtual IP (VIP); ", "format": "enum"}, "optional": true}}]}, "redistribute": {"type": "object", "properties": {"redist-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "metric": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "type": {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "nat64", "lw4o6", "isis", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'nat64': NAT64 Prefix; 'lw4o6': LW4O6 Prefix; 'isis': ISO IS-IS; 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}, "metric-type": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}}}]}, "ospf-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "process-id": {"minLength": 1, "maxLength": 128, "type": "string", "description": "OSPF process ID", "format": "string"}, "route-map-ospf": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "metric-ospf": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "ospf": {"default": 0, "type": "number", "description": "Open Shortest Path First (OSPF)", "format": "flag"}, "metric-type-ospf": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}}}]}, "ip-nat-floating-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-nat-floating-IP-forward": {"type": "string", "description": "Floating-IP as forward address", "format": "ipv6-address"}, "optional": true, "ip-nat-prefix": {"type": "string", "description": "Address", "format": "ipv6-address-plen"}}}]}, "vip-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric-vip": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "metric-type-vip": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}, "optional": true, "type-vip": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}, "route-map-vip": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}}}]}, "vip": {"default": 0, "type": "number", "description": "Virtual IP (VIP)", "format": "flag"}, "ip-nat": {"default": 0, "type": "number", "description": "IP-NAT", "format": "flag"}, "metric-ip-nat": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map-ip-nat": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "vip-floating-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "vip-address": {"type": "string", "description": "Address", "format": "ipv6-address"}, "vip-floating-IP-forward": {"type": "string", "description": "Floating-IP as forward address", "format": "ipv6-address"}}}]}, "metric-type-ip-nat": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}}}, "max-concurrent-dd": {"description": "Maximum number allowed to process DD concurrently (Number of DD process)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "process-id": {"description": "OSPFv3 process tag", "format": "string", "default": "0", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}, "passive-interface": {"type": "object", "properties": {"ve-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}}}]}, "trunk-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}}}]}, "loopback-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}}}]}, "eth-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}}}, "timers": {"type": "object", "properties": {"spf": {"type": "object", "properties": {"exp": {"type": "object", "properties": {"max-delay": {"description": "Maximum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 50000, "maximum": 2147483647, "minimum": 0, "type": "number"}, "min-delay": {"description": "Minimum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 500, "maximum": 2147483647, "minimum": 0, "type": "number"}}}}}}}, "ha-standby-extra-cost": {"description": "Extra ospf cost when there is any standby HA group (The extra cost value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "bfd-all-interfaces": {"default": 0, "optional": true, "type": "number", "description": "Enable BFD on all interfaces", "format": "flag"}, "area-list": {"minItems": 1, "items": {"type": "area"}, "uniqueItems": true, "array": [{"required": ["area-ipv4", "area-num"], "properties": {"area-ipv4": {"optional": false, "type": "string", "description": "OSPFv3 area ID in IP address format", "format": "ipv4-address"}, "virtual-link-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "transmit-delay": {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}, "value": {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}, "retransmit-interval": {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}, "optional": true, "instance-id": {"description": "OSPFv3 instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "no-summary": {"default": 0, "optional": true, "type": "number", "description": "Do not inject inter-area routes into area", "format": "flag"}, "stub": {"default": 0, "optional": true, "type": "number", "description": "Configure OSPFv3 area as stub", "format": "flag"}, "range-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "option": {"enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}, "value": {"type": "string", "description": "Area range for IPv6 prefix", "format": "ipv6-address-plen"}}}]}, "default-cost": {"description": "Set the summary-default cost of a NSSA or stub area (Stub's advertised default summary cost)", "format": "number", "default": 1, "optional": true, "maximum": 16777215, "minimum": 0, "type": "number"}, "area-num": {"description": "OSPFv3 area ID as a decimal value", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 0, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/router/ipv6/ospf/{process-id}/area/{area-ipv4}+{area-num}"}}}], "type": "array", "$ref": "/axapi/v3/router/ipv6/ospf/{process-id}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ipv6`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ipv6"
        self.a10_url="/axapi/v3/router/ipv6"
        self.DeviceProxy = ""
        self.ospf_list = []
        self.rip = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Static(A10BaseClass):
    
    """Class Description::
    Static Address Translations.

    Class static supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param nat_address: {"optional": false, "type": "string", "description": "NAT Address", "format": "ipv4-address"}
    :param vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param src_address: {"optional": false, "type": "string", "description": "Original Source Address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/inside/source/static/{src_address}+{nat_address}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "src_address","nat_address"]

        self.b_key = "static"
        self.a10_url="/axapi/v3/ip/nat/inside/source/static/{src_address}+{nat_address}"
        self.DeviceProxy = ""
        self.nat_address = ""
        self.vrid = ""
        self.src_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Interface(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"type": "number", "description": "Ethernet Interface (Ethernet interface number)", "format": "interface"}
    :param priority_cost: {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "interface"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.priority_cost = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6DestinationCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance: {"description": "Route's administrative distance (default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param v6mask: {"description": "IPv6 Destination Prefix", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}
    :param protocol: {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}
    :param priority_cost: {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param ipv6_destination: {"type": "string", "description": "IPv6 Destination Prefix", "format": "ipv6-address"}
    :param gatewayv6: {"type": "string", "description": "Match the route's gateway (next-hop) (default: match any)", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-destination-cfg"
        self.DeviceProxy = ""
        self.distance = ""
        self.v6mask = ""
        self.protocol = ""
        self.priority_cost = ""
        self.ipv6_destination = ""
        self.gatewayv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpDestinationCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance: {"description": "Route's administrative distance (default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param protocol: {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}
    :param mask: {"type": "string", "description": "Destination prefix mask", "format": "ipv4-netmask"}
    :param priority_cost: {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param ip_destination: {"type": "string", "description": "Destination prefix", "format": "ipv4-address"}
    :param gateway: {"type": "string", "description": "Match the route's gateway (next-hop) (default: match any)", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-destination-cfg"
        self.DeviceProxy = ""
        self.distance = ""
        self.protocol = ""
        self.mask = ""
        self.priority_cost = ""
        self.ip_destination = ""
        self.gateway = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Route(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_destination_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Route's administrative distance (default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "v6mask": {"description": "IPv6 Destination Prefix", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}, "protocol": {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}, "priority-cost": {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "ipv6-destination": {"type": "string", "description": "IPv6 Destination Prefix", "format": "ipv6-address"}, "gatewayv6": {"type": "string", "description": "Match the route's gateway (next-hop) (default: match any)", "format": "ipv6-address"}, "optional": true}}]}
    :param ip_destination_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Route's administrative distance (default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "protocol": {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}, "mask": {"type": "string", "description": "Destination prefix mask", "format": "ipv4-netmask"}, "priority-cost": {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "ip-destination": {"type": "string", "description": "Destination prefix", "format": "ipv4-address"}, "optional": true, "gateway": {"type": "string", "description": "Match the route's gateway (next-hop) (default: match any)", "format": "ipv4-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "route"
        self.DeviceProxy = ""
        self.ipv6_destination_cfg = []
        self.ip_destination_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VlanCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vlan: {"description": "VLAN tracking (VLAN id)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}
    :param timeout: {"minimum": 2, "type": "number", "maximum": 600, "format": "number"}
    :param priority_cost: {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vlan-cfg"
        self.DeviceProxy = ""
        self.vlan = ""
        self.timeout = ""
        self.priority_cost = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrunkCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param per_port_pri: {"description": "per port priority", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}
    :param priority_cost: {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param trunk: {"description": "trunk tracking (Trunk Number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "trunk-cfg"
        self.DeviceProxy = ""
        self.per_port_pri = ""
        self.priority_cost = ""
        self.trunk = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrackingOptions(A10BaseClass):
    
    """Class Description::
    VRRP-A tracking.

    Class tracking-options supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param interface: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet Interface (Ethernet interface number)", "format": "interface"}, "optional": true, "priority-cost": {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}
    :param vlan_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"vlan": {"description": "VLAN tracking (VLAN id)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}, "optional": true, "timeout": {"minimum": 2, "type": "number", "maximum": 600, "format": "number"}, "priority-cost": {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}
    :param trunk_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"per-port-pri": {"description": "per port priority", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "priority-cost": {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "trunk": {"description": "trunk tracking (Trunk Number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid/{vrid_val}/blade-parameters/tracking-options`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "tracking-options"
        self.a10_url="/axapi/v3/vrrp-a/vrid/{vrid_val}/blade-parameters/tracking-options"
        self.DeviceProxy = ""
        self.interface = []
        self.route = {}
        self.vlan_cfg = []
        self.trunk_cfg = []
        self.gateway = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GslbCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param group_role: {"default": 0, "type": "number", "description": "Show GSLB group role on CLI prompt", "format": "flag"}
    :param symbol: {"default": 0, "type": "number", "description": "Show \"gslb\" symbol on CLI prompt", "format": "flag"}
    :param disable: {"default": 0, "type": "number", "description": "Group status show disable", "format": "flag"}
    :param gslb_prompt: {"default": 0, "type": "number", "description": "The gslb status prompt function set", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "gslb-cfg"
        self.DeviceProxy = ""
        self.group_role = ""
        self.symbol = ""
        self.disable = ""
        self.gslb_prompt = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HistoryCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param enable: {"default": 1, "type": "number", "description": "Enable terminal history", "format": "flag"}
    :param size: {"description": "Set history buffer size (Size of history buffer, default is 256)", "format": "number", "default": 256, "maximum": 1000, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "history-cfg"
        self.DeviceProxy = ""
        self.enable = ""
        self.size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VcsCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vcs_status: {"default": 0, "type": "number", "description": "Display VCS status in prompt, eg. vMaster, vBlade", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vcs-cfg"
        self.DeviceProxy = ""
        self.vcs_status = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PromptCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hostname: {"default": 0, "type": "number", "description": "Dispaly hostname in prompt", "format": "flag"}
    :param prompt: {"default": 0, "type": "number", "description": "Configure the normal prompt format", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prompt-cfg"
        self.DeviceProxy = ""
        self.hostname = ""
        self.prompt = ""
        self.vcs_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Terminal(A10BaseClass):
    
    """Class Description::
    Set Terminal Startup Parameters.

    Class terminal supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param idle_timeout: {"description": "Set interval for closing connection when there is no input detected (Timeout in minutes, 0 means never timeout, default is 15)", "format": "number", "default": 15, "optional": true, "maximum": 60, "minimum": 0, "type": "number"}
    :param width: {"description": "Set width of the display terminal (Number of characters on a screen line, 0 means infinite, default is 80)", "format": "number", "default": 80, "optional": true, "maximum": 512, "minimum": 0, "type": "number"}
    :param length: {"description": "Set number of lines on a screen(0 for no pausing) (Number of lines on screen, 0 for no pausing, default is 24)", "format": "number", "default": 24, "optional": true, "maximum": 512, "minimum": 0, "type": "number"}
    :param editing: {"default": 0, "optional": true, "type": "number", "description": "Enable command line editing", "format": "flag"}
    :param auto_size: {"default": 1, "optional": true, "type": "number", "description": "Enable terminal length and width automatically (not work if width or length set to 0)", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/terminal`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "terminal"
        self.a10_url="/axapi/v3/terminal"
        self.DeviceProxy = ""
        self.gslb_cfg = {}
        self.history_cfg = {}
        self.idle_timeout = ""
        self.prompt_cfg = {}
        self.width = ""
        self.length = ""
        self.editing = ""
        self.auto_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PrefixCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param prefix_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter prefixes in routing updates (Name of a prefix list)", "format": "string"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param prefix_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}
    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prefix-cfg"
        self.DeviceProxy = ""
        self.ve = ""
        self.loopback = ""
        self.prefix_list = ""
        self.trunk = ""
        self.prefix_list_direction = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Prefix(A10BaseClass):
    
    """Class Description::
    Filter prefixes in routing updates.

    Class prefix supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param prefix_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}, "prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter prefixes in routing updates (Name of a prefix list)", "format": "string"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}, "ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ipv6/rip/distribute-list/prefix`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "prefix"
        self.a10_url="/axapi/v3/router/ipv6/rip/distribute-list/prefix"
        self.DeviceProxy = ""
        self.prefix_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Macoper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Index: {"type": "number", "format": "number"}
    :param Age: {"type": "number", "format": "number"}
    :param Vlan: {"minimum": 1, "type": "number", "maximum": 4094, "format": "number"}
    :param Port: {"type": "number", "format": "number"}
    :param Type: {"enum": ["Dynamic", "Static"], "type": "string", "format": "enum"}
    :param MAC_Address: {"minLength": 11, "maxLength": 17, "type": "string", "format": "mac-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "macoper"
        self.DeviceProxy = ""
        self.Index = ""
        self.Age = ""
        self.Vlan = ""
        self.Port = ""
        self.Type = ""
        self.MAC_Address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Age_time: {"type": "number", "format": "number"}
    :param macoper: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Index": {"type": "number", "format": "number"}, "optional": true, "Age": {"type": "number", "format": "number"}, "Vlan": {"minimum": 1, "type": "number", "maximum": 4094, "format": "number"}, "Port": {"type": "number", "format": "number"}, "Type": {"enum": ["Dynamic", "Static"], "type": "string", "format": "enum"}, "MAC-Address": {"minLength": 11, "maxLength": 17, "type": "string", "format": "mac-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.Age_time = ""
        self.macoper = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dynamic(A10BaseClass):
    
    """Class Description::
    Operational Status for the object dynamic.

    Class dynamic supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/mac-address/dynamic/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dynamic"
        self.a10_url="/axapi/v3/network/mac-address/dynamic/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_gw_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_attr: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_ip_cnt: {"type": "number", "format": "number"}
    :param dev_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_ip: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_session_num: {"type": "number", "format": "number"}
    :param dev_admin_preference: {"type": "number", "format": "number"}
    :param dev_session_util: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.dev_gw_state = ""
        self.dev_attr = ""
        self.dev_ip_cnt = ""
        self.dev_name = ""
        self.dev_ip = ""
        self.dev_session_num = ""
        self.dev_admin_preference = ""
        self.dev_session_util = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DevVipPortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_port_num: {"type": "number", "format": "number"}
    :param dev_vip_port_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dev-vip-port-list"
        self.DeviceProxy = ""
        self.dev_vip_port_num = ""
        self.dev_vip_port_state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_addr: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_port_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.dev_vip_addr = ""
        self.dev_vip_state = ""
        self.dev_vip_port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipServerV4List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv4: {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-server-v4-list"
        self.DeviceProxy = ""
        self.oper = {}
        self.ipv4 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DevVipPortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_port_num: {"type": "number", "format": "number"}
    :param dev_vip_port_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dev-vip-port-list"
        self.DeviceProxy = ""
        self.dev_vip_port_num = ""
        self.dev_vip_port_state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_addr: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_port_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.dev_vip_addr = ""
        self.dev_vip_state = ""
        self.dev_vip_port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipServerV6List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6: {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-server-v6-list"
        self.DeviceProxy = ""
        self.oper = {}
        self.ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DevVipPortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_port_num: {"type": "number", "format": "number"}
    :param dev_vip_port_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dev-vip-port-list"
        self.DeviceProxy = ""
        self.dev_vip_port_num = ""
        self.dev_vip_port_state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_addr: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_port_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.dev_vip_addr = ""
        self.dev_vip_state = ""
        self.dev_vip_port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipServerNameList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vip_name: {"description": "Specify a VIP name for the SLB device", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-server-name-list"
        self.DeviceProxy = ""
        self.oper = {}
        self.vip_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipServer(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vip_server_v4_list: {"minItems": 1, "items": {"type": "vip-server-v4"}, "uniqueItems": true, "array": [{"required": ["ipv4"], "properties": {"oper": {"type": "object", "properties": {"dev_vip_addr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_vip_state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev-vip-port-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}}}, "ipv4": {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}"}
    :param vip_server_v6_list: {"minItems": 1, "items": {"type": "vip-server-v6"}, "uniqueItems": true, "array": [{"required": ["ipv6"], "properties": {"oper": {"type": "object", "properties": {"dev_vip_addr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_vip_state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev-vip-port-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}}}, "ipv6": {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}/vip-server-v6/{ipv6}"}
    :param vip_server_name_list: {"minItems": 1, "items": {"type": "vip-server-name"}, "uniqueItems": true, "array": [{"required": ["vip-name"], "properties": {"oper": {"type": "object", "properties": {"dev_vip_addr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_vip_state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev-vip-port-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}}}, "vip-name": {"description": "Specify a VIP name for the SLB device", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}/vip-server-v6/{ipv6}/vip-server-name/{vip-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-server"
        self.DeviceProxy = ""
        self.oper = {}
        self.vip_server_v4_list = []
        self.vip_server_v6_list = []
        self.vip_server_name_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SlbDev(A10BaseClass):
    
    """Class Description::
    Operational Status for the object slb-dev.

    Class slb-dev supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param device_name: {"description": "Specify SLB device name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "slb-dev"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.device_name = ""
        self.vip_server = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Inbound(A10BaseClass):
    
    """Class Description::
    6rd fragmentation rules for inbound oversize packets (default: send-icmpv6).

    Class inbound supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action: {"description": "'drop': Drop Silently; 'ipv4': Use IPv4 fragmentation for oversize packets; 'ipv6': Use IPv6 Fragmentation for oversize packets; 'send-icmpv6': Send ICMP Type 2 Code 0 (Packet Too Big) (default); ", "format": "enum", "default": "send-icmpv6", "type": "string", "enum": ["drop", "ipv4", "ipv6", "send-icmpv6"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/sixrd/fragmentation/inbound`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "inbound"
        self.a10_url="/axapi/v3/cgnv6/sixrd/fragmentation/inbound"
        self.DeviceProxy = ""
        self.action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MssClamp(A10BaseClass):
    
    """Class Description::
    LSN TCP MSS Clamping.

    Class mss-clamp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param mss_subtract: {"description": "Specify the value to subtract from the TCP MSS (default: not configured)", "format": "number", "type": "number", "maximum": 1460, "minimum": 0, "optional": true}
    :param mss_value: {"description": "The max value allowed for the TCP MSS (default: not configured)},", "format": "number", "type": "number", "maximum": 1460, "minimum": 0, "optional": true}
    :param mss_clamp_type: {"description": "'fixed': Specify a fixed max value for the TCP MSS; 'subtract': Specify the value to subtract from the TCP MSS; 'none': No TCP MSS clamping (default); ", "format": "enum", "default": "none", "type": "string", "enum": ["fixed", "subtract", "none"], "optional": true}
    :param min: {"description": "Specify the min value allowed for the TCP MSS (Specify the min value allowed for the TCP MSS (default: ((576 - 60 - 60))))", "format": "number", "default": 456, "optional": true, "maximum": 1460, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/tcp/mss-clamp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "mss-clamp"
        self.a10_url="/axapi/v3/cgnv6/lsn/tcp/mss-clamp"
        self.DeviceProxy = ""
        self.mss_subtract = ""
        self.mss_value = ""
        self.mss_clamp_type = ""
        self.A10WW_min = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AvpList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param int32: {"not-list": ["int64", "string"], "type": "number", "description": "32 bits integer", "format": "number"}
    :param mandatory: {"default": 0, "type": "number", "description": "mandatory avp", "format": "flag"}
    :param string: {"description": "String (string name, max length 127 bytes)", "format": "string", "minLength": 1, "not-list": ["int32", "int64"], "maxLength": 128, "type": "string"}
    :param avp: {"type": "number", "description": "customize avps for cer to the server (avp number)", "format": "number"}
    :param int64: {"not-list": ["int32", "string"], "type": "number", "description": "64 bits integer", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "avp-list"
        self.DeviceProxy = ""
        self.int32 = ""
        self.mandatory = ""
        self.string = ""
        self.avp = ""
        self.int64 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MessageCodeList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param message_code: {"minimum": 0, "type": "number", "maximum": 2147483647, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "message-code-list"
        self.DeviceProxy = ""
        self.message_code = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Diameter(A10BaseClass):
    
    """Class Description::
    diameter template.

    Class diameter supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param avp_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"int32": {"not-list": ["int64", "string"], "type": "number", "description": "32 bits integer", "format": "number"}, "mandatory": {"default": 0, "type": "number", "description": "mandatory avp", "format": "flag"}, "string": {"description": "String (string name, max length 127 bytes)", "format": "string", "minLength": 1, "not-list": ["int32", "int64"], "maxLength": 128, "type": "string"}, "avp": {"type": "number", "description": "customize avps for cer to the server (avp number)", "format": "number"}, "int64": {"not-list": ["int32", "string"], "type": "number", "description": "64 bits integer", "format": "number"}, "optional": true}}]}
    :param service_group_name: {"description": "service group name, this is the service group that the message needs to be copied to", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param name: {"description": "diameter template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param dwr_time: {"description": "dwr health-check timer interval (in 100 milli second unit, default is 0)", "format": "number", "default": 0, "optional": true, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param avp_string: {"description": "pattern to be matched in the avp string name, max length 127 bytes", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param idle_timeout: {"description": " user sesison idle timeout (in minutes, default is 5)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param avp_code: {"description": "avp code", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}
    :param duplicate: {"default": 0, "optional": true, "type": "number", "description": "copy a message to a different server", "format": "flag"}
    :param message_code_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "message-code": {"minimum": 0, "type": "number", "maximum": 2147483647, "format": "number"}}}]}
    :param origin_realm: {"description": "origin-realm name avp", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param origin_host: {"description": "origin-host name avp", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param customize_cea: {"default": 0, "optional": true, "type": "number", "description": "customizing cea response", "format": "flag"}
    :param multiple_origin_host: {"default": 0, "optional": true, "type": "number", "description": "allowing multiple origin-host to a single server", "format": "flag"}
    :param product_name: {"description": "product name avp", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param session_age: {"description": "user session age allowed (default 10), this is not idle-time (in minutes)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param vendor_id: {"description": "vendor-id avp (Vendon Id)", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/diameter/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "diameter"
        self.a10_url="/axapi/v3/slb/template/diameter/{name}"
        self.DeviceProxy = ""
        self.avp_list = []
        self.service_group_name = ""
        self.name = ""
        self.dwr_time = ""
        self.avp_string = ""
        self.idle_timeout = ""
        self.avp_code = ""
        self.duplicate = ""
        self.message_code_list = []
        self.origin_realm = ""
        self.origin_host = ""
        self.customize_cea = ""
        self.multiple_origin_host = ""
        self.product_name = ""
        self.session_age = ""
        self.vendor_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class NssaCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param no_redistribution: {"default": 0, "type": "number", "description": "No redistribution into this NSSA area", "format": "flag"}
    :param translator_role: {"default": "candidate", "enum": ["always", "candidate", "never"], "type": "string", "description": "'always': Translate always; 'candidate': Candidate for translator (default); 'never': Do not translate; ", "format": "enum"}
    :param metric: {"description": "OSPF default metric (OSPF metric)", "format": "number", "default": 1, "maximum": 16777214, "minimum": 0, "type": "number"}
    :param nssa: {"default": 0, "type": "number", "description": "Specify a NSSA area", "format": "flag"}
    :param default_information_originate: {"default": 0, "type": "number", "description": "Originate Type 7 default into NSSA area", "format": "flag"}
    :param no_summary: {"default": 0, "type": "number", "description": "Do not send summary LSA into NSSA", "format": "flag"}
    :param metric_type: {"description": "OSPF metric type (OSPF metric type for default routes)", "format": "number", "default": 2, "maximum": 2, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "nssa-cfg"
        self.DeviceProxy = ""
        self.no_redistribution = ""
        self.translator_role = ""
        self.metric = ""
        self.nssa = ""
        self.default_information_originate = ""
        self.no_summary = ""
        self.metric_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FilterLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}
    :param plist_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}
    :param acl_name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by access-list (Name of an access-list)", "format": "string"}
    :param plist_name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by prefix-list (Name of an IP prefix-list)", "format": "string"}
    :param filter_list: {"default": 0, "type": "number", "description": "Filter networks between OSPF areas", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "filter-lists"
        self.DeviceProxy = ""
        self.acl_direction = ""
        self.plist_direction = ""
        self.acl_name = ""
        self.plist_name = ""
        self.filter_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VirtualLinkList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dead_interval: {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param message_digest_key: {"description": "Set message digest key (Key ID)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param hello_interval: {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param bfd: {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}
    :param transmit_delay: {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}
    :param virtual_link_authentication: {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}
    :param virtual_link_ip_addr: {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}
    :param virtual_link_auth_type: {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use null authentication; ", "format": "enum"}
    :param authentication_key: {"minLength": 1, "maxLength": 8, "type": "string", "description": "Set authentication key (Authentication key (8 chars))", "format": "string-rlx"}
    :param retransmit_interval: {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}
    :param md5: {"minLength": 1, "maxLength": 16, "type": "string", "description": "Use MD5 algorithm (Authentication key (16 chars))", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "virtual-link-list"
        self.DeviceProxy = ""
        self.dead_interval = ""
        self.message_digest_key = ""
        self.hello_interval = ""
        self.bfd = ""
        self.transmit_delay = ""
        self.virtual_link_authentication = ""
        self.virtual_link_ip_addr = ""
        self.virtual_link_auth_type = ""
        self.authentication_key = ""
        self.retransmit_interval = ""
        self.md5 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class StubCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param stub: {"default": 0, "type": "number", "description": "Configure OSPF area as stub", "format": "flag"}
    :param no_summary: {"default": 0, "type": "number", "description": "Do not inject inter-area routes into area", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stub-cfg"
        self.DeviceProxy = ""
        self.stub = ""
        self.no_summary = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AuthCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param authentication: {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}
    :param message_digest: {"default": 0, "type": "number", "description": "Use message-digest authentication", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "auth-cfg"
        self.DeviceProxy = ""
        self.authentication = ""
        self.message_digest = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RangeList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param area_range_prefix: {"type": "string", "description": "Area range for IPv4 prefix", "format": "ipv4-cidr"}
    :param option: {"default": "advertise", "enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "range-list"
        self.DeviceProxy = ""
        self.area_range_prefix = ""
        self.option = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Area(A10BaseClass):
    
    """Class Description::
    OSPF area parameters.

    Class area supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param filter_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}, "plist-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}, "acl-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by access-list (Name of an access-list)", "format": "string"}, "plist-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by prefix-list (Name of an IP prefix-list)", "format": "string"}, "filter-list": {"default": 0, "type": "number", "description": "Filter networks between OSPF areas", "format": "flag"}, "optional": true}}]}
    :param area_ipv4: {"optional": false, "type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}
    :param virtual_link_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-key": {"description": "Set message digest key (Key ID)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "hello-interval": {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "transmit-delay": {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}, "virtual-link-authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "virtual-link-ip-addr": {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}, "virtual-link-auth-type": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use null authentication; ", "format": "enum"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Set authentication key (Authentication key (8 chars))", "format": "string-rlx"}, "retransmit-interval": {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}, "optional": true, "md5": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Use MD5 algorithm (Authentication key (16 chars))", "format": "string-rlx"}}}]}
    :param shortcut: {"description": "'default': Set default shortcutting behavior; 'disable': Disable shortcutting through the area; 'enable': Enable shortcutting through the area; ", "format": "enum", "default": "default", "type": "string", "enum": ["default", "disable", "enable"], "optional": true}
    :param range_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-range-prefix": {"type": "string", "description": "Area range for IPv4 prefix", "format": "ipv4-cidr"}, "optional": true, "option": {"default": "advertise", "enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}}}]}
    :param default_cost: {"description": "Set the summary-default cost of a NSSA or stub area (Stub's advertised default summary cost)", "format": "number", "default": 1, "optional": true, "maximum": 16777215, "minimum": 0, "type": "number"}
    :param area_num: {"description": "OSPF area ID as a decimal value", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 0, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/area/{area_ipv4}+{area_num}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "area_ipv4","area_num"]

        self.b_key = "area"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/area/{area_ipv4}+{area_num}"
        self.DeviceProxy = ""
        self.nssa_cfg = {}
        self.filter_lists = []
        self.area_ipv4 = ""
        self.virtual_link_list = []
        self.stub_cfg = {}
        self.shortcut = ""
        self.auth_cfg = {}
        self.range_list = []
        self.default_cost = ""
        self.area_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SessionList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param protocol: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param inbound: {"type": "number", "format": "number"}
    :param age: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param cpu: {"type": "number", "format": "number"}
    :param nat_address: {"type": "string", "format": "ipv4-address"}
    :param nat_port: {"type": "number", "format": "number"}
    :param flags: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param nat_pool_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param inside_port: {"type": "number", "format": "number"}
    :param outbound: {"type": "number", "format": "number"}
    :param inside_address: {"type": "string", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "session-list"
        self.DeviceProxy = ""
        self.protocol = ""
        self.inbound = ""
        self.age = ""
        self.cpu = ""
        self.nat_address = ""
        self.nat_port = ""
        self.flags = ""
        self.nat_pool_name = ""
        self.inside_port = ""
        self.outbound = ""
        self.inside_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"protocol": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "inbound": {"type": "number", "format": "number"}, "age": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "cpu": {"type": "number", "format": "number"}, "nat-address": {"type": "string", "format": "ipv4-address"}, "nat-port": {"type": "number", "format": "number"}, "flags": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "nat-pool-name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "inside-port": {"type": "number", "format": "number"}, "outbound": {"type": "number", "format": "number"}, "optional": true, "inside-address": {"type": "string", "format": "ipv4-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.session_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FullConeSession(A10BaseClass):
    
    """Class Description::
    Operational Status for the object full-cone-session.

    Class full-cone-session supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/full-cone-session/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "full-cone-session"
        self.a10_url="/axapi/v3/cgnv6/lsn/full-cone-session/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dns64Virtualserver(A10BaseClass):
    
    """Class Description::
    Create a DNS64 Virtual Server.

    Class dns64-virtualserver supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param use_if_ip: {"description": "Use Interface IP", "format": "flag", "default": 0, "type": "number", "plat-pos-list": ["soft-ax"], "optional": true}
    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"protocol": {"optional": false, "enum": ["dns-udp"], "type": "string", "description": "'dns-udp': DNS service over UDP; ", "format": "enum"}, "precedence": {"default": 0, "optional": true, "type": "number", "description": "Set auto NAT pool as higher precedence for source NAT", "format": "flag"}, "auto": {"default": 0, "optional": true, "type": "number", "description": "Configure auto NAT for the vport", "format": "flag"}, "template-policy": {"description": "Policy Template (Policy template name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/template/policy"}, "port-number": {"description": "Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "template-dns": {"description": "DNS template (DNS template name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/template/dns"}, "service-group": {"description": "Bind a Service Group to this Virtual Server (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/cgnv6/service-group"}, "action": {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "pool": {"description": "Specify NAT pool or pool group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/dns64-virtualserver/{name}/port/{port-number}+{protocol}"}
    :param name: {"description": "CGNV6 Virtual Server Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param template_policy: {"description": "Policy template name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/template/policy"}
    :param vrid: {"description": "Join a vrrp group (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param enable_disable_action: {"description": "'enable': Enable Virtual Server (default); 'disable': Disable Virtual Server; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param policy: {"default": 0, "optional": true, "type": "number", "description": "Policy template", "format": "flag"}
    :param netmask: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IP subnet mask", "format": "ipv4-netmask-brief"}
    :param ip_address: {"description": "IP Address", "format": "ipv4-address", "type": "string", "modify-not-allowed": 1, "not": "ipv6-address", "optional": true}
    :param ipv6_address: {"description": "IPV6 address", "format": "ipv6-address", "type": "string", "modify-not-allowed": 1, "not": "ip-address", "optional": true}
    :param ethernet: {"optional": true, "plat-pos-list": ["soft-ax"], "type": "number", "description": "Ethernet interface", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/dns64-virtualserver/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "dns64-virtualserver"
        self.a10_url="/axapi/v3/cgnv6/dns64-virtualserver/{name}"
        self.DeviceProxy = ""
        self.use_if_ip = ""
        self.port_list = []
        self.name = ""
        self.template_policy = ""
        self.vrid = ""
        self.enable_disable_action = ""
        self.policy = ""
        self.netmask = ""
        self.ip_address = ""
        self.ipv6_address = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


